summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/spinbox2.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/spinbox2.h')
-rw-r--r--kalarm/lib/spinbox2.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/kalarm/lib/spinbox2.h b/kalarm/lib/spinbox2.h
index b1d2927d..f83db252 100644
--- a/kalarm/lib/spinbox2.h
+++ b/kalarm/lib/spinbox2.h
@@ -1,5 +1,5 @@
/*
- * spinbox2.h - spin box with extra pair of spin buttons (for Qt 3)
+ * spinbox2.h - spin box with extra pair of spin buttons (for TQt 3)
* Program: kalarm
* Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
*
@@ -53,25 +53,26 @@ class ExtraSpinBox;
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class SpinBox2 : public QFrame
+class SpinBox2 : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit SpinBox2(TQWidget* parent = 0, const char* name = 0);
+ explicit SpinBox2(TQWidget* tqparent = 0, const char* name = 0);
/** Constructor.
* @param minValue The minimum value which the spin box can have.
* @param maxValue The maximum value which the spin box can have.
* @param step The (unshifted) step interval for the right-hand spin buttons.
* @param step2 The (unshifted) step interval for the left-hand spin buttons.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
SpinBox2(int minValue, int maxValue, int step = 1, int step2 = 1,
- TQWidget* parent = 0, const char* name = 0);
+ TQWidget* tqparent = 0, const char* name = 0);
/** Sets whether the spin box can be changed by the user.
* @param readOnly True to set the widget read-only, false to set it read-write.
*/
@@ -281,10 +282,10 @@ class SpinBox2 : public QFrame
class MainSpinBox : public SpinBox
{
public:
- MainSpinBox(SpinBox2* sb2, TQWidget* parent, const char* name = 0)
- : SpinBox(parent, name), owner(sb2) { }
- MainSpinBox(int minValue, int maxValue, int step, SpinBox2* sb2, TQWidget* parent, const char* name = 0)
- : SpinBox(minValue, maxValue, step, parent, name), owner(sb2) { }
+ MainSpinBox(SpinBox2* sb2, TQWidget* tqparent, const char* name = 0)
+ : SpinBox(tqparent, name), owner(sb2) { }
+ MainSpinBox(int minValue, int maxValue, int step, SpinBox2* sb2, TQWidget* tqparent, const char* name = 0)
+ : SpinBox(minValue, maxValue, step, tqparent, name), owner(sb2) { }
void tqsetAlignment(int a) { editor()->tqsetAlignment(a); }
virtual TQString mapValueToText(int v) { return owner->mapValueToText(v); }
virtual int mapTextToValue(bool* ok) { return owner->mapTextToValue(ok); }
@@ -298,8 +299,8 @@ class SpinBox2 : public QFrame
enum { NO_BUTTON = -1, UP, DOWN, UP2, DOWN2 };
static int mReverseLayout; // widgets are mirrored right to left
- TQFrame* mUpdown2Frame; // tqcontains visible part of the extra pair of spin buttons
- TQFrame* mSpinboxFrame; // tqcontains the main spin box
+ TQFrame* mUpdown2Frame; // contains visible part of the extra pair of spin buttons
+ TQFrame* mSpinboxFrame; // contains the main spin box
ExtraSpinBox* mUpdown2; // the extra pair of spin buttons
MainSpinBox* mSpinbox; // the visible spin box
SpinMirror* mSpinMirror; // image of the extra pair of spin buttons
@@ -53,25 +53,26 @@ class ExtraSpinBox;
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -53,25 +53,26 @@ class ExtraSpinBox;
* @param step The (unshifted) step interval for the right-hand spin buttons.
* @param step2 The (unshifted) step interval for the left-hand spin buttons.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/